Crate universal_tool_core
universal_
tool_
core
0.2.9
All Items
Crate Items
Re-exports
Modules
Traits
Attribute Macros
Derive Macros
Crate
universal_
tool_
core
Re-exports

pub use
schemars
;
Modules

error
prelude
The
prelude
module provides a single, convenient import for all essential library items. This is just a convenience - users control their own application structure.
Traits

Json
Schema
A type which can be described as a JSON Schema document.
Attribute Macros

universal_
tool
Attribute macro for individual tool methods within a universal_tool_router impl block.
universal_
tool_
router
The main attribute macro for defining universal tools.
Derive Macros

Json
Schema